@@ -567,7 +567,7 @@ impl TypeInfo {
                 // size
                 if self.size < 8000 && self.size > 0 {
                     s.push_str("(");
-                    let _ = itoa::fmt(&mut *s, self.size);
+                    s.push_str(itoa::Buffer::new().format(self.size));
                     s.push_str(")");
                 } else {
                     s.push_str("(max)");
