@@ -133,6 +133,12 @@ impl<DB: Database> PoolConnection<DB> {
 impl<DB: Database> Drop for PoolConnection<DB> {
     fn drop(&mut self) {
         if self.live.is_some() {
+            #[cfg(not(feature = "_rt-async-std"))]
+            if let Ok(handle) = sqlx_rt::Handle::try_current() {
+                handle.spawn(self.return_to_pool());
+            }
+
+            #[cfg(feature = "_rt-async-std")]
             sqlx_rt::spawn(self.return_to_pool());
         }
     }
