@@ -8,7 +8,9 @@ use crate::decode::Decode;
 use crate::encode::{Encode, IsNull};
 use crate::error::BoxDynError;
 use crate::postgres::types::numeric::{PgNumeric, PgNumericSign};
-use crate::postgres::{PgArgumentBuffer, PgTypeInfo, PgValueFormat, PgValueRef, Postgres};
+use crate::postgres::{
+    PgArgumentBuffer, PgHasArrayType, PgTypeInfo, PgValueFormat, PgValueRef, Postgres,
+};
 use crate::types::Type;
 
 impl Type<Postgres> for BigDecimal {
@@ -17,18 +19,12 @@ impl Type<Postgres> for BigDecimal {
     }
 }
 
-impl Type<Postgres> for [BigDecimal] {
-    fn type_info() -> PgTypeInfo {
+impl PgHasArrayType for BigDecimal {
+    fn array_type_info() -> PgTypeInfo {
         PgTypeInfo::NUMERIC_ARRAY
     }
 }
 
-impl Type<Postgres> for Vec<BigDecimal> {
-    fn type_info() -> PgTypeInfo {
-        <[BigDecimal] as Type<Postgres>>::type_info()
-    }
-}
-
 impl TryFrom<PgNumeric> for BigDecimal {
     type Error = BoxDynError;
 
