@@ -5,7 +5,9 @@ use std::convert::TryInto;
 use crate::decode::Decode;
 use crate::encode::{Encode, IsNull};
 use crate::error::BoxDynError;
-use crate::postgres::{PgArgumentBuffer, PgTypeInfo, PgValueFormat, PgValueRef, Postgres};
+use crate::postgres::{
+    PgArgumentBuffer, PgHasArrayType, PgTypeInfo, PgValueFormat, PgValueRef, Postgres,
+};
 use crate::types::Type;
 
 impl Type<Postgres> for MacAddress {
@@ -18,22 +20,12 @@ impl Type<Postgres> for MacAddress {
     }
 }
 
-impl Type<Postgres> for [MacAddress] {
-    fn type_info() -> PgTypeInfo {
+impl PgHasArrayType for MacAddress {
+    fn array_type_info() -> PgTypeInfo {
         PgTypeInfo::MACADDR_ARRAY
     }
 }
 
-impl Type<Postgres> for Vec<MacAddress> {
-    fn type_info() -> PgTypeInfo {
-        <[MacAddress] as Type<Postgres>>::type_info()
-    }
-
-    fn compatible(ty: &PgTypeInfo) -> bool {
-        <[MacAddress] as Type<Postgres>>::compatible(ty)
-    }
-}
-
 impl Encode<'_, Postgres> for MacAddress {
     fn encode_by_ref(&self, buf: &mut PgArgumentBuffer) -> IsNull {
         buf.extend_from_slice(&self.bytes()); // write just the address
