@@ -52,3 +52,23 @@ impl<'r> Decode<'r, Sqlite> for String {
         value.text().map(ToOwned::to_owned)
     }
 }
+
+impl<'q> Encode<'q, Sqlite> for Cow<'q, str> {
+    fn encode(self, args: &mut Vec<SqliteArgumentValue<'q>>) -> IsNull {
+        args.push(SqliteArgumentValue::Text(self));
+
+        IsNull::No
+    }
+
+    fn encode_by_ref(&self, args: &mut Vec<SqliteArgumentValue<'q>>) -> IsNull {
+        args.push(SqliteArgumentValue::Text(self.clone()));
+
+        IsNull::No
+    }
+}
+
+impl<'r> Decode<'r, Sqlite> for Cow<'r, str> {
+    fn decode(value: SqliteValueRef<'r>) -> Result<Self, BoxDynError> {
+        value.text().map(Cow::Borrowed)
+    }
+}
